package ru.dima.weather;

import ru.dima.weather.city.IpInfoService;
import ru.dima.weather.city.IpProvider;
import ru.dima.weather.city.IpProviderCLISelector;
import ru.dima.weather.city.IpProviderRegistry;
import ru.dima.weather.cli.CLIInputReader;
import ru.dima.weather.cli.WeatherProviderCLISelector;
import ru.dima.weather.http.HttpRequester;
import ru.dima.weather.provider.OpenWeatherMapWeatherProvider;
import ru.dima.weather.provider.WeatherProviderRegistry;

import java.util.ArrayList;

/*
 1. Брать текущий IP
 2. Определять город по текущему IP
 3. По городу определять погоду на 7 дней (предоставлять пользователю выбор сайта, на котором искать погоду)
 */
public class WeatherApp {

    public static void main(String[] args) {
        var httpRequester = new HttpRequester();
        var weatherProviderRegistry = new WeatherProviderRegistry();

        IpProviderRegistry ipProviderRegistry = new IpProviderRegistry();
        IpInfoService ipInfoService = new IpInfoService(httpRequester);

        IpProviderCLISelector ipProviderCLISelector = new IpProviderCLISelector(new CLIInputReader(System.in), ipProviderRegistry.registerWeatherProvider(ipInfoService));
        ipProviderCLISelector.selectIpProviderFromCLI();

        var openWeatherMapProvider = new OpenWeatherMapWeatherProvider(httpRequester, "29ed5ca47c3d0c32385b18f1e82e522f");
        weatherProviderRegistry.registerWeatherProvider(openWeatherMapProvider);

        var weatherProviderCliSelector = new WeatherProviderCLISelector(new CLIInputReader(System.in), weatherProviderRegistry);
        var weatherProviderSelectedByUser = weatherProviderCliSelector.selectWeatherProviderFromCLI();

      System.out.println(openWeatherMapProvider.getWeeklyWeatherInCity(ipInfoService.getCurrentCityViaIP()));
    }
}
