package ru.dima.weather.city;

import org.junit.jupiter.api.Test;
import ru.dima.weather.http.HttpRequester;
import ru.dima.weather.provider.MultiDaysWeatherInfo;
import ru.dima.weather.provider.OpenWeatherMapWeatherProvider;
import ru.dima.weather.provider.WeatherInfo;

import java.util.Random;

import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.ArgumentMatchers.anyString;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

public class OpenWeatherMapWeatherProviderTest {


    @Test
    void testGetName() {
        HttpRequester httpRequester = mock(HttpRequester.class);
        OpenWeatherMapWeatherProvider OpenWeatherMapWeatherProvider = new OpenWeatherMapWeatherProvider(httpRequester, "29ed5ca47c3d0c32385b18f1e82e522f");

        OpenWeatherMapWeatherProvider.getName();
        assertEquals("open-weather-map", OpenWeatherMapWeatherProvider.getName(), "open-weather-map");
    }
    @Test
    void TestMultiDaysWeatherInfo_T() {
        HttpRequester httpRequester = mock(HttpRequester.class);
        String ft = "{\"list\": [{\"main\": {\"temp\": 22.5}}, {\"main\": {\"temp\": 19.85}}, {\"main\": {\"temp\": 20.97}}, {\"main\": {\"temp\": 22.19}}, {\"main\": {\"temp\": 25.41}}, {\"main\": {\"temp\": 26.21}}, {\"main\": {\"temp\": 22.53}}]}";


        when(httpRequester.getString(anyString())).thenReturn(ft);

        OpenWeatherMapWeatherProvider openWeatherMapWeatherProvider = new OpenWeatherMapWeatherProvider(httpRequester , "29ed5ca47c3d0c32385b18f1e82e522f" );
        var weatherInfo = openWeatherMapWeatherProvider.getWeeklyWeatherInCity("Москва");
        assertEquals("MultiDaysWeatherInfo{perDayWeather=[WeatherInfo{temperature=22.5}, WeatherInfo{temperature=19.85}, WeatherInfo{temperature=20.97}, WeatherInfo{temperature=22.19}, WeatherInfo{temperature=25.41}, WeatherInfo{temperature=26.21}, WeatherInfo{temperature=22.53}]}",weatherInfo,"s");

    }
    @Test
    void TestMultiDaysWeatherInfo_F() {
        HttpRequester httpRequester = mock(HttpRequester.class);
        String ffd = "{\"list\": [{\"main\": {\"temp\": 22.5}}, {\"main\": {\"temp\": 19.85}}, {\"main\": {\"temp\": 20.97}}, {\"main\": {\"temp\": 22.19}}, {\"main\": {\"temp\": 25.41}}, {\"main\": {\"temp\": 26.21}}, {\"main\": {\"temp\": 22.53}}]}";


        when(httpRequester.getString(anyString())).thenReturn(ffd);

        OpenWeatherMapWeatherProvider openWeatherMapWeatherProvider = new OpenWeatherMapWeatherProvider(httpRequester , "29ed5ca47c3d0c32385b18f1e82e522f" );
        Random random = new Random();
        var ran = random.toString();
        var weatherInfo = openWeatherMapWeatherProvider.getWeeklyWeatherInCity(ran);
        assertEquals("MultiDaysWeatherInfo{perDayWeather=[WeatherInfo{temperature=22.5}, WeatherInfo{temperature=19.85}, WeatherInfo{temperature=20.97}, WeatherInfo{temperature=22.19}, WeatherInfo{temperature=25.41}, WeatherInfo{temperature=26.21}, WeatherInfo{temperature=22.53}]}",weatherInfo,"s");

    }
}